==> tuia-advert-center-api-2.2.44-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertMaterialTestPlanDataQueryDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import io.swagger.models.auth.In;

import java.util.List;

public class AdvertMaterialTestPlanDataQueryDto {

    //有效的广告ids集合
    private List<Long> advertIds;
    //有效的素材ids集合
    private List<Long> materialIds;
    //有效的广告计划id
    private List<Long> planIds;

    private String advertName;

    private String materialName;

    private Integer skip;

    private Integer limit;

    private String orderby;


    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public List<Long> getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(List<Long> materialIds) {
        this.materialIds = materialIds;
    }

    public List<Long> getPlanIds() {
        return planIds;
    }

    public void setPlanIds(List<Long> planIds) {
        this.planIds = planIds;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Integer getSkip() {
        return skip;
    }

    public void setSkip(Integer skip) {
        this.skip = skip;
    }

    public Integer getLimit() {
        return limit;
    }

    public void setLimit(Integer limit) {
        this.limit = limit;
    }

    public String getOrderby() {
        return orderby;
    }

    public void setOrderby(String orderby) {
        this.orderby = orderby;
    }
}

==> tuia-advert-center-api-2.5.55-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertMaterialTestPlanDataQueryDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;
import java.util.List;

public class AdvertMaterialTestPlanDataQueryDto implements Serializable {

    private static final long serialVersionUID = 2705205608057787511L;
    //有效的广告ids集合
    private List<Long> advertIds;
    //有效的素材ids集合
    private List<Long> materialIds;
    //有效的广告计划id
    private List<Long> planIds;

    private String advertName;

    private String materialName;

    private Integer skip;

    private Integer limit;

    private String orderby;

    private Integer advertType;

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public List<Long> getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(List<Long> materialIds) {
        this.materialIds = materialIds;
    }

    public List<Long> getPlanIds() {
        return planIds;
    }

    public void setPlanIds(List<Long> planIds) {
        this.planIds = planIds;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Integer getSkip() {
        return skip;
    }

    public void setSkip(Integer skip) {
        this.skip = skip;
    }

    public Integer getLimit() {
        return limit;
    }

    public void setLimit(Integer limit) {
        this.limit = limit;
    }

    public String getOrderby() {
        return orderby;
    }

    public void setOrderby(String orderby) {
        this.orderby = orderby;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }
}
